pub struct Sentiment {
positivity: i8,
}Fields
positivity: i8How positive the sentiment is.
Using i8 to reduce on-disk memory footprint. Semantically, this value is -1 <= x <= 1.
Implementations
Sourceimpl Sentiment
impl Sentiment
Sourcepub const ALLY: f32 = 0.3
pub const ALLY: f32 = 0.3
Substantial positive sentiments: NPC may go out of their way to help actors associated with the target, greet them, etc.
const DEFAULT: Self
Sourcepub const ENEMY: f32 = -0.6
pub const ENEMY: f32 = -0.6
Very negative sentiments: NPC may confront the actor, get aggressive with them, or even use force against them.
Sourcepub const FRIEND: f32 = 0.6
pub const FRIEND: f32 = 0.6
Very positive sentiments: NPC may join the actor as a companion, encourage them to join their faction, etc.
Sourcepub const HERO: f32 = 0.8
pub const HERO: f32 = 0.8
Extremely positive sentiments: NPC may switch sides to join the actor’s faction, protect them at all costs, turn against friends for them, etc. Verging on cult-like behaviour.
Sourcepub const NEGATIVE: f32 = -0.1
pub const NEGATIVE: f32 = -0.1
Minor negative sentiments: NPC might be less willing to provide information, give worse trade deals, etc.
Sourcepub const POSITIVE: f32 = 0.1
pub const POSITIVE: f32 = 0.1
Minor positive sentiments: NPC might be more willing to provide information, give better trade deals, etc.
Sourcepub const RIVAL: f32 = -0.3
pub const RIVAL: f32 = -0.3
Substantial negative sentiments: NPC may reject attempts to trade or avoid actors associated with the target, insult them, but will not use physical force.
Sourcepub const VILLAIN: f32 = -0.8
pub const VILLAIN: f32 = -0.8
Extremely negative sentiments: NPC may aggressively persue or hunt down the actor, organise others around them to do the same, and will generally try to harm the actor in any way they can.
fn value(&self) -> f32
Sourcepub fn change_by(&mut self, change: f32, cap: f32)
pub fn change_by(&mut self, change: f32, cap: f32)
Change the sentiment toward the given target by the given amount, capping out at the given value.
Sourcepub fn limit_below(&mut self, cap: f32)
pub fn limit_below(&mut self, cap: f32)
Limit the sentiment to the given value, either positive or negative. The
resulting sentiment is guaranteed to be less than the cap (at least,
as judged by Sentiment::is).
fn decay(&mut self, rng: &mut impl Rng, dt: f32)
Sourcefn is_redundant(&self) -> bool
fn is_redundant(&self) -> bool
Return true if the sentiment can be forgotten without changing
anything (i.e: is entirely neutral, the default stance).